<?php

namespace Modules\Pd\Http\Controllers;

use Exception;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Illuminate\Support\Facades\DB;
use Modules\Hr\Entities\Employee;
use Modules\Pd\Entities\DailyProduction;
use Modules\Pp\Entities\CustomerPlan;
use Modules\Pp\Entities\Machinary;
use Modules\St\Entities\Product;

class DailyProductionController extends Controller
{
    public function productionSupervisor()
    {
        try {
            $employees = Employee::all();
            $result = array();
            foreach ($employees as $emp) {
                array_push($result, [
                    "img" => "",
                    "id" => $emp->employee_id,
                    "value" => $emp->name_withinitial,
                ]);
            }
            $responseBody = $this->responseBody(true, "DailyProductionController", "productionSupervisor", $result);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "DailyProductionController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }



    public function manufacturingOrderNumber()
    {
        try {
            $result = CustomerPlan::select(['customer_order_plan_id', 'manufacturing_order_number'])->get();

            $responseBody = $this->responseBody(true, "DailyProductionController", "productionSupervisor", $result);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "DailyProductionController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }




    public function product($id)
    {
        try {
             $query = 'SELECT DISTINCT st_products.product_id,st_products.product_primary_id,st_products.product_name FROM pp_machinery_plans INNER JOIN pp_customer_order_plans_data ON pp_machinery_plans.customer_order_plan_data_id = pp_customer_order_plans_data.customer_order_plan_data_id
             INNER JOIN st_products ON pp_machinery_plans.product_id = st_products.product_id
             WHERE pp_customer_order_plans_data.customer_order_plan_id = "'.$id.'"';
             $result = DB::select($query);
             $data = [];
            for ($j = 0; $j < count($result); $j++) {
                array_push($data, [
                    "img" => "",
                    "id" => $result[0]->product_id,
                    "value" => $result[0]->product_name,
                ]);
            }
            $responseBody = $this->responseBody(true, "DailyProductionController", "product", $data);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "DailyProductionController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }



    public function machine($id)
    {
        try {
            $query = 'SELECT DISTINCT pp_machinery.machinery_id,pp_machinery.machinery_name FROM pp_machinery_plans INNER JOIN pp_customer_order_plans_data ON pp_machinery_plans.customer_order_plan_data_id = pp_customer_order_plans_data.customer_order_plan_data_id
            INNER JOIN pp_machinery ON pp_machinery_plans.machine_id = pp_machinery.machinery_id
            WHERE pp_customer_order_plans_data.customer_order_plan_id = "' . $id . '"';

            $machines = DB::select($query);
            $responseBody = $this->responseBody(true, "DailyProductionController", "machine", $machines);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "DailyProductionController", "error", $exception->getMessage());
        }

        return response()->json(["data" => $responseBody]);
    }


    public function save(Request $request)
    {

        try {
            $dailyProduction = new DailyProduction();
            $dailyProduction->date = $request->get('date');
            $dailyProduction->supervisor_id = $request->get('supervisor');
            $dailyProduction->customer_order_plan_id = $request->get('manufacturing_order_no');
            $dailyProduction->product_id = $request->get('product_id');
            $dailyProduction->machine_id = $request->get('machine_id');
            $dailyProduction->refferance_no = $request->get('refferance_no');
            $dailyProduction->day_quantity = $request->get('day_quantity');
            $dailyProduction->night_quantity = $request->get('night_quantity');
            $dailyProduction->save();
            $responseBody = $this->responseBody(true, "DailyProductionController", "save", true);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "DailyProductionController", "error", $exception->getMessage());
        }

        return response()->json(["data" => $responseBody]);
    }



    public function getDailyProduction($id)
    {
        try {
            $dailyProduction = DailyProduction::find($id);
            $employee = Employee::find($dailyProduction->supervisor_id);
            $dailyProduction->supervisor = $employee->name_withinitial;
            $product = Product::find($dailyProduction->product_id);
            $dailyProduction->product = $product->product_name;
            $responseBody = $this->responseBody(true, "DailyProductionController", "productionSupervisor", $dailyProduction);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "DailyProductionController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }



    public function update(Request $request, $id)
    {

        try {
            $dailyProduction = DailyProduction::find($id);
            $dailyProduction->date = $request->get('date');
            $dailyProduction->supervisor_id = $request->get('supervisor');
            $dailyProduction->customer_order_plan_id = $request->get('manufacturing_order_no');
            $dailyProduction->product_id = $request->get('product_id');
            $dailyProduction->machine_id = $request->get('machine_id');
            $dailyProduction->refferance_no = $request->get('refferance_no');
            $dailyProduction->day_quantity = $request->get('day_quantity');
            $dailyProduction->night_quantity = $request->get('night_quantity');
            $dailyProduction->update();
            $responseBody = $this->responseBody(true, "DailyProductionController", "update", true);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "DailyProductionController", "error", $exception->getMessage());
        }

        return response()->json(["data" => $responseBody]);
    }




    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
